package com.jiuqi.sql;

import java.util.Date;

/* loaded from: com_jiuqi_sql.jar:com/jiuqi/sql/InputDataSet.class */
public abstract class InputDataSet {
    private boolean active;
    private InputRecordBuffer buffer;
    private DataSetListener listener = null;
    private FieldInfoList fieldInfos = new FieldInfoList();

    public abstract InputDataSetMetaData getMetaData() throws DBException;

    protected abstract boolean getNextRecord(InputRecordBuffer inputRecordBuffer) throws DBException;

    protected abstract void initFields(FieldInfoList fieldInfoList) throws DBException;

    protected abstract InputRecordBuffer internalOpen() throws DBException;

    protected abstract void internalClose() throws DBException;

    public void resetListener(DataSetListener listerner) {
        this.listener = listerner;
    }

    private FieldInfo findField(String fieldName) throws DBException {
        int index = this.fieldInfos.find(fieldName);
        if (index < 0) {
            throw new DBException(String.valueOf(fieldName) + " Not Exists");
        }
        FieldInfo result = this.fieldInfos.get(index);
        return result;
    }

    protected InputRecordBuffer recordBuffer() {
        return this.buffer;
    }

    public void open() throws DBException {
        if (!isActive()) {
            initFields(this.fieldInfos);
            this.buffer = internalOpen();
            this.fieldInfos.refreshFinder();
            this.active = true;
            if (this.listener != null) {
                this.listener.afterEvent(new DataSetEvent(this, 1));
            }
        }
    }

    public void first() throws DBException {
        throw new DBException("尚未实现！");
    }

    public boolean isActive() {
        return this.active;
    }

    public boolean next() throws DBException {
        boolean result;
        do {
            result = getNextRecord(this.buffer);
            if (!result) {
                break;
            }
        } while (this.buffer.isDeleted());
        return result;
    }

    public void close() throws DBException {
        if (isActive()) {
            internalClose();
            this.active = false;
            if (this.listener != null) {
                this.listener.afterEvent(new DataSetEvent(this, 2));
            }
        }
    }

    public int fieldIndexOf(String fieldName) {
        int result = this.fieldInfos.find(fieldName);
        return result < 0 ? result : result + 1;
    }

    public boolean getBoolean(int index) throws DBException {
        return this.buffer.readBoolean(this.fieldInfos.get(index - 1));
    }

    public boolean getBoolean(String fieldName) throws DBException {
        return this.buffer.readBoolean(findField(fieldName));
    }

    public int getInt(int index) throws DBException {
        return this.buffer.readInt(this.fieldInfos.get(index - 1));
    }

    public int getInt(String fieldName) throws DBException {
        return this.buffer.readInt(findField(fieldName));
    }

    public long getLong(int index) throws DBException {
        return this.buffer.readLong(this.fieldInfos.get(index - 1));
    }

    public long getLong(String fieldName) throws DBException {
        return this.buffer.readLong(findField(fieldName));
    }

    public String getString(int index) throws DBException {
        return this.buffer.readString(this.fieldInfos.get(index - 1));
    }

    public String getString(String fieldName) throws DBException {
        return this.buffer.readString(findField(fieldName));
    }

    public double getDouble(int index) throws DBException {
        return this.buffer.readDouble(this.fieldInfos.get(index - 1));
    }

    public double getDouble(String fieldName) throws DBException {
        return this.buffer.readDouble(findField(fieldName));
    }

    public Date readDate(int index) throws DBException {
        return this.buffer.readDate(this.fieldInfos.get(index - 1));
    }

    public Date readDate(String fieldName) throws DBException {
        return this.buffer.readDate(findField(fieldName));
    }

    public Date getDate(int index) throws DBException {
        return this.buffer.readDate(this.fieldInfos.get(index - 1));
    }

    public Date getDate(String fieldName) throws DBException {
        return this.buffer.readDate(findField(fieldName));
    }

    private Object getObject(FieldInfo fieldInfo) throws DBException {
        switch (fieldInfo.type) {
            case 1:
                boolean value = this.buffer.readBoolean(fieldInfo);
                if (this.buffer.wasNull()) {
                    return null;
                }
                return new Boolean(value);
            case 2:
                Date value2 = this.buffer.readDate(fieldInfo);
                if (this.buffer.wasNull()) {
                    return null;
                }
                return value2;
            case 3:
                double value3 = this.buffer.readDouble(fieldInfo);
                if (this.buffer.wasNull()) {
                    return null;
                }
                return new Double(value3);
            case 4:
            default:
                return null;
            case 5:
                int value4 = this.buffer.readInt(fieldInfo);
                if (this.buffer.wasNull()) {
                    return null;
                }
                return new Integer(value4);
            case 6:
                String value5 = this.buffer.readString(fieldInfo);
                if (this.buffer.wasNull()) {
                    return null;
                }
                return value5;
            case 7:
            case 8:
                long value6 = this.buffer.readLong(fieldInfo);
                if (this.buffer.wasNull()) {
                    return null;
                }
                return new Long(value6);
            case DataTypes.BLOB /* 9 */:
                return null;
        }
    }

    public final Object getObject(int index) throws DBException {
        return getObject(this.fieldInfos.get(index - 1));
    }

    public final Object getObject(String fieldName) throws DBException {
        return getObject(findField(fieldName));
    }

    public boolean wasNull() throws DBException {
        return this.buffer.wasNull();
    }
}
